using System;
using CookComputing.XmlRpc;

namespace MPS.BLL.MetaWeblogAPI.MetaWeblog
{
	/// <summary>
	/// XmlRpc definitions for Metaweblog API methods and structures
	/// </summary>

	[XmlRpcMissingMapping(MappingAction.Ignore)]
	public struct PostInfo
	{
		[XmlRpcMissingMapping(MappingAction.Error)]
		[XmlRpcMember]
		public DateTime dateCreated;
		[XmlRpcMissingMapping(MappingAction.Error)]
		[XmlRpcMember]
		public string description;
		[XmlRpcMissingMapping(MappingAction.Error)]
		[XmlRpcMember]
		public string title;

		public string[] categories;
		public string link;
		public string permalink;
		[XmlRpcMember]
		public object postid;
		public string userid;
	}

	public struct CategoryInfo
	{
		public string description;
		public string htmlUrl;
		public string rssUrl;
		public string title;
		public string categoryid;
	}

	public struct FileData
	{
		public byte[] bits;
		public string name;
		public string type;
	}

	public struct UrlData
	{
		public string url;
	}

	public interface IMetaWeblog
	{
		[XmlRpcMethod("metaWeblog.editPost",
		   Description = "Updates and existing post to a designated blog "
		   + "using the metaWeblog API. Returns true if completed.")]
		object editPost(
		  string postid,
		  string username,
		  string password,
		  PostInfo postInfo,
		  bool publish);

		[XmlRpcMethod("metaWeblog.getCategories",
		   Description = "Retrieves a list of valid categories for a post "
		   + "using the metaWeblog API. Returns the metaWeblog categories "
		   + "struct collection.")]
		CategoryInfo[] getCategories(
		  string blogid,
		  string username,
		  string password);

		[XmlRpcMethod("metaWeblog.getPost",
		   Description = "Retrieves an existing post using the metaWeblog "
		   + "API. Returns the metaWeblog struct.")]
		PostInfo getPost(
		  string postid,
		  string username,
		  string password);

		[XmlRpcMethod("metaWeblog.getRecentPosts",
		   Description = "Retrieves a list of the most recent existing post "
		   + "using the metaWeblog API. Returns the metaWeblog struct collection.")]
		PostInfo[] getRecentPosts(
		  string blogid,
		  string username,
		  string password,
		  int numberOfPosts);

		[XmlRpcMethod("metaWeblog.newPost",
		   Description = "Makes a new post to a designated blog using the "
		   + "metaWeblog API. Returns postid as a string.")]
		string newPost(
		  string blogid,
		  string username,
		  string password,
		  PostInfo post,
		  bool publish);

		[XmlRpcMethod("metaWeblog.newMediaObject",
	  Description = "Makes a new file to a designated blog using the "
	  + "metaWeblog API. Returns url as a string of a struct.")]
		UrlData newMediaObject(
		  string blogid,
		  string username,
		  string password,
		  FileData file);
	}
}